# 0.8.0 (Thu Nov 21 2024)

#### 🚀 Enhancement

- fix strip() issue for choices [#78](https://github.com/ReproNim/reproschema-py/pull/78) ([@yibeichan](https://github.com/yibeichan) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))

#### 🐛 Bug Fix

- adding id check to the validation [#68](https://github.com/ReproNim/reproschema-py/pull/68) ([@djarecka](https://github.com/djarecka) [@satra](https://github.com/satra))
- [pre-commit.ci] pre-commit autoupdate [#76](https://github.com/ReproNim/reproschema-py/pull/76) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- [MAINT] support python 3.13 [#77](https://github.com/ReproNim/reproschema-py/pull/77) ([@Remi-Gau](https://github.com/Remi-Gau))
- [pre-commit.ci] pre-commit autoupdate [#72](https://github.com/ReproNim/reproschema-py/pull/72) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- [FIX] debugging redcap2reproschema during converting HBCD [#61](https://github.com/ReproNim/reproschema-py/pull/61) ([@yibeichan](https://github.com/yibeichan) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- [pre-commit.ci] pre-commit autoupdate [#69](https://github.com/ReproNim/reproschema-py/pull/69) ([@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- ignore CHANGELOG.md for codespell [#71](https://github.com/ReproNim/reproschema-py/pull/71) ([@yibeichan](https://github.com/yibeichan) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))
- fix typos [#70](https://github.com/ReproNim/reproschema-py/pull/70) ([@yibeichan](https://github.com/yibeichan))

#### Authors: 5

- [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot])
- Dorota Jarecka ([@djarecka](https://github.com/djarecka))
- Remi Gau ([@Remi-Gau](https://github.com/Remi-Gau))
- Satrajit Ghosh ([@satra](https://github.com/satra))
- Yibei Chen ([@yibeichan](https://github.com/yibeichan))

---

# 0.7.2 (Thu Jul 11 2024)

#### 🐛 Bug Fix

- enable org auto token [#67](https://github.com/ReproNim/reproschema-py/pull/67) ([@satra](https://github.com/satra))
- Update .autorc to fix author issue [#66](https://github.com/ReproNim/reproschema-py/pull/66) ([@satra](https://github.com/satra))
- Fixed bug in redcap2reproschema with items id not matching item filname and redcap variable… [#65](https://github.com/ReproNim/reproschema-py/pull/65) ([@Evan8456](https://github.com/Evan8456) [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot]))

#### Authors: 3

- [@pre-commit-ci[bot]](https://github.com/pre-commit-ci[bot])
- Evan Ng ([@Evan8456](https://github.com/Evan8456))
- Satrajit Ghosh ([@satra](https://github.com/satra))
